Thomas,

 

These two examples work in our in-house systems with the current drop. Let me test in JLSE to see if I can find what is going on.

 

Carlos

 

From: "Peterka, Thomas" <tpeterka@mcs.anl.gov>
Date: Friday, November 15, 2019 at 8:34 AM
To: "Rosales-fernandez, Carlos" <carlos.rosales-fernandez@intel.com>
Cc: Ecp-aurora-sdk-discuss <ecp-aurora-sdk-discuss@lists.jlse.anl.gov>
Subject: Re: [Ecp-aurora-sdk-discuss] New A21 SDK coming to JLSE later today

 

Hi Carlos,

 

I think there may be something wrong with this latest drop, because SYCL code that used to work now crashes, and reverting to the old version version of dpcpp/2019.9.30.013b continues to work.

 

Specifically, I see two problems:

 

1. My test of USM generates the following run time error:

symbol lookup error: ./fixed: undefined symbol: _ZN2cl4sycl6detail3usm12alignedAllocEmmRKNS0_7contextENS0_3usm5allocE

 

The code is this:

 

auto dev = Queue.get_device();
auto ctxt = Queue.get_context();
sycl::usm_allocator<int, sycl::usm::alloc::host> alloc(ctxt, dev);

std::vector<int, decltype(alloc)> n(alloc);
n.resize(1);

 

The last line, resize, is where the error occurs. The same problem happens if I give the size in the constructor and don’t call the resize.

 

2. The following trivial example generates a segmentation fault:

 

sycl::queue Queue;

sycl::buffer<sycl::cl_int, 1> Buffer(4);
sycl::range<1> NumOfWorkItems{Buffer.get_count()};

 

Queue.submit([&](sycl::handler &cgh)
{
    auto Accessor = Buffer.get_access<sycl::access::mode::write>(cgh);
    cgh.parallel_for<class FillBuffer>(NumOfWorkItems, [=](sycl::id<1> WIid)
    {

        Accessor[WIid] = (cl::sycl::cl_int)WIid.get(0);

    });

});

The seg fault happens in the parallel_for loop.

 

 

Tom

-----------------
Tom Peterka
Mathematics and Computer Science Division
Argonne National Laboratory
9700 S. Cass Ave.
Lemont, IL 60439
Bldg 240, Rm 2148
e-mail: tpeterka@mcs.anl.gov
web: www.mcs.anl.gov/~tpeterka
phone: 630-252-7198



On Nov 11, 2019, at 3:19 PM, Rosales-fernandez, Carlos via Ecp-aurora-sdk-discuss <ecp-aurora-sdk-discuss@lists.jlse.anl.gov> wrote:

 

Hi all,

 

Just a heads up that we will be pushing a new SDK around 9pm Central Time to JLSE. At that  point if you have scripts using module names only ,without an explicit version, your default loads will shift to the new SDK version. Older versions will remain in the system as usual. 

 

A notice will go out at that time with a link to the release notes.

 

Regards,

Carlos

 

-- 
Ecp-aurora-sdk-discuss mailing list
Ecp-aurora-sdk-discuss@lists.jlse.anl.gov
https://lists.jlse.anl.gov/mailman/listinfo/ecp-aurora-sdk-discuss